==> ginkgo-hpc-docs-1.9.0-3-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/namespacegko_1_1experimental_1_1distributed.js <==
var namespacegko_1_1experimental_1_1distributed =
[
    [ "preconditioner", "namespacegko_1_1experimental_1_1distributed_1_1preconditioner.html", "namespacegko_1_1experimental_1_1distributed_1_1preconditioner" ],
    [ "DistributedBase", "classgko_1_1experimental_1_1distributed_1_1DistributedBase.html", "classgko_1_1experimental_1_1distributed_1_1DistributedBase" ],
    [ "index_map", "structgko_1_1experimental_1_1distributed_1_1index__map.html", "structgko_1_1experimental_1_1distributed_1_1index__map" ],
    [ "Matrix", "classgko_1_1experimental_1_1distributed_1_1Matrix.html", "classgko_1_1experimental_1_1distributed_1_1Matrix" ],
    [ "Partition", "classgko_1_1experimental_1_1distributed_1_1Partition.html", "classgko_1_1experimental_1_1distributed_1_1Partition" ],
    [ "Vector", "classgko_1_1experimental_1_1distributed_1_1Vector.html", "classgko_1_1experimental_1_1distributed_1_1Vector" ],
    [ "comm_index_type", "namespacegko_1_1experimental_1_1distributed.html#aaaa8462bbc1d1c5d4c2b8cafb81df9a5", null ],
    [ "assembly_mode", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4e", [
      [ "communicate", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4ea01b922d867dfc910199b04faca436f37", null ],
      [ "local_only", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4ea4f2603689acfa6e2968100b353bbb547", null ]
    ] ],
    [ "index_space", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947b", [
      [ "local", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947baf5ddaf0ca7929578b408c909429f68f2", null ],
      [ "non_local", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947ba9182221a9ec0a65321d5a206c9c174ca", null ],
      [ "combined", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947ba507d922378ecab8e10b81dcbc2ff8bf3", null ]
    ] ],
    [ "assemble_rows_from_neighbors", "namespacegko_1_1experimental_1_1distributed.html#aae57602561df89a74decb3316696981b", null ],
    [ "build_partition_from_local_range", "namespacegko_1_1experimental_1_1distributed.html#ae0368295654a9d8455731832a88ffc8c", null ],
    [ "build_partition_from_local_size", "namespacegko_1_1experimental_1_1distributed.html#a6fff69d2898fefe193012da079a2fef0", null ],
    [ "make_temporary_conversion", "namespacegko_1_1experimental_1_1distributed.html#a38521559ec782871cee97d15656cbd49", null ],
    [ "make_temporary_conversion", "namespacegko_1_1experimental_1_1distributed.html#a1090c398cde41fae9f7b215f20e21bf1", null ],
    [ "precision_dispatch", "namespacegko_1_1experimental_1_1distributed.html#ae834447464baacc73ee8d2bc6a0d61a0", null ],
    [ "precision_dispatch_real_complex", "namespacegko_1_1experimental_1_1distributed.html#a76b1f78aad396f2a87ae070e0b11c1f3", null ],
    [ "precision_dispatch_real_complex", "namespacegko_1_1experimental_1_1distributed.html#a87ee066b077fed30ab6e2da949faef6e", null ],
    [ "precision_dispatch_real_complex", "namespacegko_1_1experimental_1_1distributed.html#a6348d5cfc6451aa9f12509e5658de943", null ]
];

==> ginkgo-hpc-docs-1.10.0-1-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/namespacegko_1_1experimental_1_1distributed.js <==
var namespacegko_1_1experimental_1_1distributed =
[
    [ "preconditioner", "namespacegko_1_1experimental_1_1distributed_1_1preconditioner.html", "namespacegko_1_1experimental_1_1distributed_1_1preconditioner" ],
    [ "DistributedBase", "classgko_1_1experimental_1_1distributed_1_1DistributedBase.html", "classgko_1_1experimental_1_1distributed_1_1DistributedBase" ],
    [ "index_map", "classgko_1_1experimental_1_1distributed_1_1index__map.html", "classgko_1_1experimental_1_1distributed_1_1index__map" ],
    [ "Matrix", "classgko_1_1experimental_1_1distributed_1_1Matrix.html", "classgko_1_1experimental_1_1distributed_1_1Matrix" ],
    [ "Partition", "classgko_1_1experimental_1_1distributed_1_1Partition.html", "classgko_1_1experimental_1_1distributed_1_1Partition" ],
    [ "RowGatherer", "classgko_1_1experimental_1_1distributed_1_1RowGatherer.html", "classgko_1_1experimental_1_1distributed_1_1RowGatherer" ],
    [ "Vector", "classgko_1_1experimental_1_1distributed_1_1Vector.html", "classgko_1_1experimental_1_1distributed_1_1Vector" ],
    [ "comm_index_type", "namespacegko_1_1experimental_1_1distributed.html#a13b7760affb031fee59d385754eaaffb", null ],
    [ "assembly_mode", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4e", [
      [ "communicate", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4ea01b922d867dfc910199b04faca436f37", null ],
      [ "local_only", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4ea4f2603689acfa6e2968100b353bbb547", null ]
    ] ],
    [ "index_space", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947b", [
      [ "local", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947baf5ddaf0ca7929578b408c909429f68f2", null ],
      [ "non_local", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947ba9182221a9ec0a65321d5a206c9c174ca", null ],
      [ "combined", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947ba507d922378ecab8e10b81dcbc2ff8bf3", null ]
    ] ],
    [ "assemble_rows_from_neighbors", "namespacegko_1_1experimental_1_1distributed.html#aae57602561df89a74decb3316696981b", null ],
    [ "build_partition_from_local_range", "namespacegko_1_1experimental_1_1distributed.html#ae0368295654a9d8455731832a88ffc8c", null ],
    [ "build_partition_from_local_size", "namespacegko_1_1experimental_1_1distributed.html#a6fff69d2898fefe193012da079a2fef0", null ],
    [ "make_temporary_conversion", "namespacegko_1_1experimental_1_1distributed.html#a38521559ec782871cee97d15656cbd49", null ],
    [ "make_temporary_conversion", "namespacegko_1_1experimental_1_1distributed.html#a1090c398cde41fae9f7b215f20e21bf1", null ],
    [ "precision_dispatch", "namespacegko_1_1experimental_1_1distributed.html#ae834447464baacc73ee8d2bc6a0d61a0", null ],
    [ "precision_dispatch_real_complex", "namespacegko_1_1experimental_1_1distributed.html#a76b1f78aad396f2a87ae070e0b11c1f3", null ],
    [ "precision_dispatch_real_complex", "namespacegko_1_1experimental_1_1distributed.html#a87ee066b077fed30ab6e2da949faef6e", null ],
    [ "precision_dispatch_real_complex", "namespacegko_1_1experimental_1_1distributed.html#a6348d5cfc6451aa9f12509e5658de943", null ]
];
